Tutorials
=========

The easiest way to get familiar with scVI is to follow along with our tutorials!
The tutorials are accessible on the sidebar to the left. Some are designed to work seamlessly in Google Colab, a free cloud computing platform. These tutorials have a Colab badge in their introduction. In general, these tutorials are designed to work with the latest installable version of scVI. Previous versions of the tutorials are avaiable by changing the Read the Docs version (avaialble at the bottom left of the page if viewing on a computer).

To download the tutorials:

1. Click the Colab badge below
2. Open the tutorial
3. Download it with the option in the file menu.
4. When you execute the notebook yourself, please set your own `save_path`.

Also, please pardon the code at the beginning of tutorials that is used for testing our notebooks. Testing the notebooks is important so we do not introduce any bugs!

|Open In Colab|

.. |Open In Colab| image:: https://colab.research.google.com/assets/colab-badge.svg
    :target: https://colab.research.google.com/github/yoseflab/scVI/blob/stable


.. toctree::
   :maxdepth: 1
   :numbered:
   :hidden:

   basic_tutorial
   data_loading
   totalvi
   cite_scrna_integration_w_totalVI
   harmonization
   scanpy
   autozi
   gimvi
   linear_decoder
   autotune
